# define OPENSSL_NO_EC_NISTP_64_GCC_128
# define OPENSSL_NO_CMS
# define OPENSSL_NO_COMP
# define OPENSSL_NO_EGD
# define OPENSSL_NO_GMP
# define OPENSSL_NO_JPAKE
# define OPENSSL_NO_KRB5
# define OPENSSL_NO_MD2
# define OPENSSL_NO_MDC2
# define OPENSSL_NO_PSK
# define OPENSSL_NO_RC5
# define OPENSSL_NO_RFC3779
# define OPENSSL_NO_RSAX
# define OPENSSL_NO_SCTP
# define OPENSSL_NO_SEED
# define OPENSSL_NO_SHA0
# define OPENSSL_NO_SRP
# define OPENSSL_NO_SSL2
# define OPENSSL_NO_SSL3
# define OPENSSL_NO_SSL3_METHOD
# define OPENSSL_NO_STORE
# define OPENSSL_NO_BUF_FREELISTS
# define OPENSSL_NO_HEARTBEATS
# define OPENSSL_NO_DYNAMIC_ENGINE

# define OPENSSL_THREADS
